# Realpy Engine

[![CodeQL](https://github.com/RealPy-Engine/realpy-core/actions/workflows/codeql-analysis.yml/badge.svg?branch=master)](https://github.com/RealPy-Engine/realpy-core/actions/workflows/codeql-analysis.yml)
[![Build Status](https://dev.azure.com/iconer/Realpy/_apis/build/status/RealPy-Engine.realpy-core?branchName=refs%2Fpull%2F20%2Fmerge)](https://dev.azure.com/iconer/Realpy/_build/latest?definitionId=1&branchName=refs%2Fpull%2F20%2Fmerge)

